@@ -1,13 +1,12 @@
 ;;; latexinfo.el - Support for LaTeXinfo files.
 
-;; Copyright (C) 1993 Marc Gemis <makke@wins.uia.ac.be>
+;; Copyright (C) 1993 Free Software Foundation, Inc.
 
 ;; Author: Marc Gemis <makke@wins.uia.ac.be>
-;; Version: $Id: latexinfo.el,v 1.10 2008/07/23 07:22:54 stephent Exp $
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 ;; 
 ;; This program is distributed in the hope that it will be useful,
@@ -99,11 +98,11 @@ This fails when the user types in the label of something else"
        (TeX-arg-literal " ")
        (TeX-arg-free TeX-arg-define-label "Node name")
        (TeX-arg-literal ", ")
-       (TeX-arg-free TeX-arg-label "Next node")
+       (TeX-arg-free TeX-arg-ref "Next node")
        (TeX-arg-literal ", ")
-       (TeX-arg-free TeX-arg-label "Previous node")
+       (TeX-arg-free TeX-arg-ref "Previous node")
        (TeX-arg-literal ", ")
-       (TeX-arg-free TeX-arg-label "Up node"))
+       (TeX-arg-free TeX-arg-ref "Up node"))
      '("setfilename" TeX-arg-file)
 
      '("var" t)
@@ -137,8 +136,8 @@ This fails when the user types in the label of something else"
      '("copyright" nil)
      '("sp" nil)
 
-     '("xref" TeX-arg-label)
-     '("pxref" TeX-arg-label)
+     '("xref" TeX-arg-ref)
+     '("pxref" TeX-arg-ref)
      '("inforef"
        (TeX-arg-literal "{")
        (TeX-arg-free "Name of node")
@@ -176,6 +175,7 @@ This fails when the user types in the label of something else"
 
     ;; need the following stuff to let xref and pxref work
     (make-local-variable 'LaTeX-section-label)
-    (setq LaTeX-section-label ""))))
+    (setq LaTeX-section-label "")))
+ LaTeX-dialect)
 
 ;;; latexinfo.el ends here
